@@ -120,8 +120,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 from ._jsii import *
 
@@ -140,11 +140,11 @@ class CloudFrontToApiGateway(
     def __init__(
         self,
         scope: aws_cdk.core.Construct,
-        id: str,
+        id: builtins.str,
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        insert_http_security_headers: typing.Optional[bool] = None,
+        insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -168,24 +168,24 @@ class CloudFrontToApiGateway(
 
         jsii.create(CloudFrontToApiGateway, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return jsii.get(self, "apiGateway")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudFrontWebDistribution")
     def cloud_front_web_distribution(
         self,
     ) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
         return jsii.get(self, "cloudFrontWebDistribution")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudFrontLoggingBucket")
     def cloud_front_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "cloudFrontLoggingBucket")
 
-    @builtins.property
+    @builtins.property # type: ignore
     @jsii.member(jsii_name="edgeLambdaFunctionVersion")
     def edge_lambda_function_version(
         self,
@@ -208,7 +208,7 @@ class CloudFrontToApiGatewayProps:
         *,
         existing_api_gateway_obj: aws_cdk.aws_apigateway.RestApi,
         cloud_front_distribution_props: typing.Any = None,
-        insert_http_security_headers: typing.Optional[bool] = None,
+        insert_http_security_headers: typing.Optional[builtins.bool] = None,
     ) -> None:
         """
         :param existing_api_gateway_obj: Existing instance of api.RestApi object. Default: - None
@@ -218,7 +218,7 @@ class CloudFrontToApiGatewayProps:
         summary:
         :summary:: The properties for the CloudFrontToApiGateway Construct
         """
-        self._values = {
+        self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
         }
         if cloud_front_distribution_props is not None:
@@ -233,7 +233,9 @@ class CloudFrontToApiGatewayProps:
         default
         :default: - None
         """
-        return self._values.get("existing_api_gateway_obj")
+        result = self._values.get("existing_api_gateway_obj")
+        assert result is not None, "Required property 'existing_api_gateway_obj' is missing"
+        return result
 
     @builtins.property
     def cloud_front_distribution_props(self) -> typing.Any:
@@ -242,21 +244,23 @@ class CloudFrontToApiGatewayProps:
         default
         :default: - Default props are used
         """
-        return self._values.get("cloud_front_distribution_props")
+        result = self._values.get("cloud_front_distribution_props")
+        return result
 
     @builtins.property
-    def insert_http_security_headers(self) -> typing.Optional[bool]:
+    def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         """Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
         default
         :default: - true
         """
-        return self._values.get("insert_http_security_headers")
+        result = self._values.get("insert_http_security_headers")
+        return result
 
-    def __eq__(self, rhs) -> bool:
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
-    def __ne__(self, rhs) -> bool:
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
         return not (rhs == self)
 
     def __repr__(self) -> str:
