@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_apigateway._jsii
 import aws_cdk.aws_cloudfront._jsii
@@ -19,9 +19,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-cloudfront-apigateway",
-    "1.61.0",
+    "1.62.0",
     __name__[0:-6],
-    "aws-cloudfront-apigateway@1.61.0.jsii.tgz",
+    "aws-cloudfront-apigateway@1.62.0.jsii.tgz",
 )
 
 __all__ = [
